@@ -43,4 +43,7 @@ dets      = [i for i in range(det_num * int64_num * 2)]
 coeffs    = [float(i/det_num)   for i in range(det_num)]
 coeffs_s2 = [float(i*2/det_num) for i in range(det_num)]
 
-det_test  = [1, 2, 3, 2, 1, 3]
\ No newline at end of file
+det_test  = [1, 2, 3, 2, 1, 3]
+
+orb_up_test = [0, 65, 128, 129]
+orb_dn_test = [1, 64, 128, 129]
